pub struct RgenConfig {
pub templates_dir: Option<String>,
pub base: Option<String>,
pub prefixes: BTreeMap<String, String>,
pub rdf: Option<RdfConfig>,
}Fields
templates_dir: Option<String>Templates directory (relative to config file)
base: Option<String>Base IRI for RDF operations
prefixes: BTreeMap<String, String>Global prefixes for RDF operations
rdf: Option<RdfConfig>RDF configuration
Implementations
Sourceimpl RgenConfig
impl RgenConfig
Sourcepub fn discover_and_load(start_dir: &Path) -> Result<Option<(Self, PathBuf)>>
pub fn discover_and_load(start_dir: &Path) -> Result<Option<(Self, PathBuf)>>
Load rgen.toml from the given directory, walking up the tree
Sourcepub fn load_from_file(config_path: &Path) -> Result<Self>
pub fn load_from_file(config_path: &Path) -> Result<Self>
Load rgen.toml from a specific file
Sourcepub fn resolve_path(&self, config_dir: &Path, path: &str) -> PathBuf
pub fn resolve_path(&self, config_dir: &Path, path: &str) -> PathBuf
Resolve a path relative to the config file directory
Sourcepub fn templates_dir_path(&self, config_dir: &Path) -> PathBuf
pub fn templates_dir_path(&self, config_dir: &Path) -> PathBuf
Get templates directory path, resolved relative to config file
Sourcepub fn rdf_file_paths(&self, config_dir: &Path) -> Vec<PathBuf>
pub fn rdf_file_paths(&self, config_dir: &Path) -> Vec<PathBuf>
Get RDF file paths, resolved relative to config file
Sourcepub fn rdf_inline_content(&self) -> Vec<String>
pub fn rdf_inline_content(&self) -> Vec<String>
Get inline RDF content